@@ -63,7 +63,7 @@ fin <- tclVar(FALSE)
 
         u1 <- sort(theta)
         u1 <- as.vector(u1)
-        z <- seq(1, max(u1), by = (max(u1)/1000))
+        z <- seq(1, max(u1), by = (max(u1)/3500))
         z <- round(z)
         z1 <- z[2:length(z)] - z[1:(length(z) - 1)]
         h <- mean(z1)
@@ -290,7 +290,7 @@ poly.but <- tkbutton(tt, text=" Polygon ", command=polyfunc);
 tkgrid(point.but, poly.but)
 tkgrid(tklabel(tt,text="    "))
 
-label1 <- tclVar("To stop selection, let the cursur on the active graph, click on the right button of the mouse and stop")
+label1 <- tclVar("To stop selection, let the cursor on the active graph, click on the right button of the mouse and stop")
 label11 <- tklabel(tt,justify = "center", wraplength = "3i", text=tclvalue(label1))
 tkconfigure(label11, textvariable=label1)
 tkgrid(label11,columnspan=2)
@@ -303,7 +303,7 @@ tkgrid(tklabel(tt,text="    "))
    
 }
 
-labelText7 <- tclVar("Non interactive selection")
+labelText7 <- tclVar("Preselected sites")
 label7 <- tklabel(tt,justify = "center", wraplength = "3i",text=tclvalue(labelText7))
 tkconfigure(label7, textvariable=labelText7)
 tkgrid(label7,columnspan=2)
